capture log close
log using vfdatamaker.log, replace                       
clear
set memory 800m
set matsize 6600

******************************************************************************************************************
**
**          This program takes T2 and T2LT files (GCM, A1B runs post 1979) from Chad and computes anomaly values
**		Then combines with UAH, RSS, HADAT etc observations to construct multivariate trend comparison database
**
******************************************************************************************************************


*
*	SEQUENCE
*
*     GET CHAD'S GCM-LT DATA AND GROUP INTO ENSEMBLE MEANS 			--> model_lt.dta
*	GET CHAD'S GCM-MT DATA AND GROUP INTO ENSEMBLE MEANS 			--> model_mt.dta
*	GET UAH LT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA  	--> uahlt.dta
*	GET UAH MT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA  	--> uahmt.dta
*	GET RSS LT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA  	--> rsslt.dta
*	GET RSS MT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA  	--> rssmt.dta
*	GET HADAT DATA (LT&MT)FOR TROPICS, ESTIMATE TREND AND SAVE DATA 	--> had.dta
*	GET RICH DATA (LT&MT) FOR TROPICS, ESTIMATE TREND AND SAVE DATA 	--> rich.dta

* 	READ IN .DTA FILES AND MERGE INTO lt.dta and mt.dta



**************************************************************************************************************************
*
*	GET CHAD'S GCM-LT DATA AND GROUP INTO ENSEMBLE MEANS
*
**************************************************************************************************************************

insheet using ensemble.T2LT.csv					// reads in data
	sum

	egen month=fill(1/12 1/12)					// generates month variable
	egen year=seq(), from(1850) to(2099) block(12) 		// generates year variable
	drop if year<1979
	drop if year>2009
	sum

	drop v1								// drop num column and renames v1-v57
	mkmat v2-v58, matrix(vv)
	drop v2-v58
	svmat vv, names(v)
	sum


	* Center and put onto decadal scale
	forvalues i=1/57 {						// starts do-loop
		egen ave=mean(v`i')
		replace v`i'=v`i'-ave
		replace v`i'=120*v`i'
		drop ave
				}

*	GROUP INTO ENSEMBLE MEANS 	
	generate mlt1 =(v1)
	generate mlt2 =(v2+v3+v4+v5+v6)/5
	generate mlt3 =(v7)
	generate mlt4 =(v8)
	generate mlt5 =(v9)
	generate mlt6 =(v10)
	generate mlt7 =(v11)
	generate mlt8 =(v12)
	generate mlt9 =(v13+v14)/2
	generate mlt10=(v15+v16+v17+v18+v19+v20)/6
	generate mlt11=(v21+v22+v23+v24+v25)/5
	generate mlt12=(v26+v27+v28)/3
	generate mlt13=(v29)
	generate mlt14=(v30)
	generate mlt15=(v31)
	generate mlt16=(v32)
	generate mlt17=(v33+v34+v35)/3
	generate mlt18=(v36+v37+v38+v39+v40)/5
	generate mlt19=(v41+v42+v43+v44)/4
	generate mlt20=(v45+v46+v47+v48+v49+v50+v51)/7
	generate mlt21=(v52+v53+v54+v55)/4
	generate mlt22=(v56)
	generate mlt23=(v57)
	keep year month mlt1-mlt23

	sum

	capture save "model_lt.dta", replace

 *		Do ARMA Regs to get trends
	generate t = ym(year,month)
	tsset t
	format t %tm
	forvalues i=1/23 {
		arima mlt`i' t, ar(1/6)
		test t=0.215
				}




**************************************************************************************************************************
*
*           GET CHAD'S GCM-MT DATA AND GROUP INTO ENSEMBLE MEANS
*
**************************************************************************************************************************

clear
insheet using ensemble.T2.csv						// reads in data
	sum

	egen month=fill(1/12 1/12)					// generates month variable
	egen year=seq(), from(1850) to(2099) block(12) 		// generates year variable
	drop if year<1979
	drop if year>2009
	sum

	drop v1								// drop num column and renames v1-v57
	mkmat v2-v58, matrix(vv)
	drop v2-v58
	svmat vv, names(v)
	sum


	* Center and put onto decadal scale
	forvalues i=1/57 {						// starts do-loop
		egen ave=mean(v`i')
		replace v`i'=v`i'-ave
		replace v`i'=120*v`i'
		drop ave
				}

*	GROUP INTO ENSEMBLE MEANS 	
	generate mmt1 =(v1)
	generate mmt2 =(v2+v3+v4+v5+v6)/5
	generate mmt3 =(v7)
	generate mmt4 =(v8)
	generate mmt5 =(v9)
	generate mmt6 =(v10)
	generate mmt7 =(v11)
	generate mmt8 =(v12)
	generate mmt9 =(v13+v14)/2
	generate mmt10=(v15+v16+v17+v18+v19+v20)/6
	generate mmt11=(v21+v22+v23+v24+v25)/5
	generate mmt12=(v26+v27+v28)/3
	generate mmt13=(v29)
	generate mmt14=(v30)
	generate mmt15=(v31)
	generate mmt16=(v32)
	generate mmt17=(v33+v34+v35)/3
	generate mmt18=(v36+v37+v38+v39+v40)/5
	generate mmt19=(v41+v42+v43+v44)/4
	generate mmt20=(v45+v46+v47+v48+v49+v50+v51)/7
	generate mmt21=(v52+v53+v54+v55)/4
	generate mmt22=(v56)
	generate mmt23=(v57)
	keep year month mmt1-mmt23

	sum
	capture save "model_mt.dta", replace
 
*		Do ARMA Regs to get trends
	generate t = ym(year,month)
	tsset t
	format t %tm
	forvalues i=1/23 {
		arima mmt`i' t, ar(1/6)
		test t=0.215
				}


**************************************************************************************************************************
*
*	GET UAH LT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA
*
**************************************************************************************************************************

// Obtain data from UAH (T2LT layer)
clear
insheet uah1 using http://vortex.nsstc.uah.edu/data/msu/t2lt/uahncdc.lt
	split uah1
	keep uah11-uah16 uah19 uah112
	rename uah11 year
	rename uah12 month
	rename uah112 ltuah
	drop if _n == 1 | year=="1978" | year=="Year" | year=="Trend" 
	destring, replace

*                     Center and put onto decadal scale
	drop if year>2009
	egen ave=mean(ltuah)
	replace ltuah=ltuah-ave
	replace ltuah=120*ltuah
	drop ave

*                     Do ARMA Regs to get trends
	generate t = ym(year,month)
	format t %tm
	tsset t

	arima ltuah t, ar(1/6)				
		test t=0.215


*                    Write Data set
	keep year month ltuah 
	capture save "uahlt.dta", replace


**************************************************************************************************************************
*
*	GET UAH MT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA
*
**************************************************************************************************************************

// Obtain data from UAH (T2 layer)
clear
insheet uah1 using http://vortex.nsstc.uah.edu/data/msu/t2/uahncdc.mt
	split uah1
	keep uah11-uah16 uah19 uah112
	rename uah11 year
	rename uah12 month
	rename uah112 mtuah
	drop if _n == 1 | year=="1978" | year=="Year" | year=="Trend" 
	destring, replace

*                     Center and put onto decadal scale
	drop if year>2009
	egen ave=mean(mtuah)
	replace mtuah=mtuah-ave
	replace mtuah=120*mtuah
	drop ave


*                     Do ARMA Regs to get trends
	generate t = ym(year,month)
	format t %tm
	tsset t

	arima mtuah t, ar(1/6)				// data up to end of sample if greater than 1999
		test t=0.215


*                    Write Data set
	keep mtuah 
	capture save "uahmt.dta", replace



**************************************************************************************************************************
*
*	GET RSS LT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA
*
**************************************************************************************************************************

// Obtain data from RSS (TLT Layer)
clear
insheet rss1 using http://www.remss.com/data/msu/monthly_time_series/RSS_Monthly_MSU_AMSU_Channel_TLT_Anomalies_Land_and_Ocean_v03_2.txt
	split rss1
	keep rss11-rss14 rss110-rss111
	rename rss11 year
	rename rss12 month
	rename rss14 ltrss
	drop if _n == 1 | _n == 2 | _n == 3 
	destring, replace

*                     Center and put onto decadal scale
	drop if year>2009
	egen ave=mean(ltrss)
	replace ltrss=ltrss-ave
	replace ltrss=120*ltrss
	drop ave

*                     Do ARMA Regs to get trends
	generate t = ym(year,month)
	format t %tm

	tsset t
	arima lt t, ar(1/6)				// data up to end of sample 
		test t=0.215


*                    Write Data set
	keep year month ltrss
	capture save "rsslt.dta", replace




**************************************************************************************************************************
*
*	GET RSS MT DATA, EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA
*
**************************************************************************************************************************

// Obtain data from RSS (TMT Layer)
clear
insheet rss1 using http://www.remss.com/data/msu/monthly_time_series/RSS_Monthly_MSU_AMSU_Channel_TMT_Anomalies_Land_and_Ocean_v03_2.txt
	split rss1
	keep rss11-rss14 rss110-rss111
	rename rss11 year
	rename rss12 month
	rename rss14 mtrss
	drop if _n == 1 | _n == 2 | _n == 3 
	destring, replace

*                     Center and put onto decadal scale
	drop if year>2009
	egen ave=mean(mtrss)
	replace mtrss=mtrss-ave
	replace mtrss=120*mtrss
	drop ave


*                     Do ARMA Regs to get trends
	generate t = ym(year,month)
	format t %tm
	tsset t

	arima mt t, ar(1/6)				// data up to end of sample 
		test t=0.215


*                    Write Data set
	keep mtrss
	capture save "rssmt.dta", replace




**************************************************************************************************************************
*
*	GET HADAT DATA (LT&MT), EXTRACT TROPICS, ESTIMATE TREND AND SAVE DATA
*
**************************************************************************************************************************

// Obtain data from HadAT 
clear
insheet had1 using http://hadobs.metoffice.com/hadat/msu/anomalies/hadat_msu_tropical.txt
	split had1
	drop if _n == 1 | _n == 2 | _n == 3 | _n == 4 | _n == 5 | _n == 6 | _n == 7 | _n == 8 | _n == 9 | _n == 10 | _n == 11 ///
		| _n == 12 | _n == 13 | _n == 14 | _n == 15 | _n == 16 | _n == 17 | _n == 18 | _n == 19 | _n == 20 | _n == 21 | _n == 22 

	keep had12-had14 
	rename had12 year
	rename had13 lthad
	rename had14 mthad
	destring, replace
	keep if year>1978
	egen month=fill(1/12 1/12)					// generates month variable


*                     Center and put onto decadal scale
	egen ave=mean(lthad)
	replace lthad=120*(lthad-ave)
	drop ave

	egen ave=mean(mthad)
	replace mthad=120*(mthad-ave)
	drop ave

*                     Do ARMA Regs to get trends
	generate t = ym(year,month)
	format t %tm

	tsset t
	arima lthad t, ar(1/6)				// data up to end of sample 
		test t=0.215

	tsset t
	arima mthad t, ar(1/6)				// data up to end of sample 
		test t=0.215


*                    Write Data set
	keep year month lthad mthad
	capture save "had.dta", replace


**************************************************************************************************************************
*
*	GET RICH DATA (LT&MT) FOR TROPICS, ESTIMATE TREND AND SAVE DATA
*
**************************************************************************************************************************

clear

insheet using balloonwide.csv			// Get RICH balloon data (generated by R code, see SI)
	generate year=int(monthdec)
	generate month=1+int(12*(monthdec-year))
	generate t = ym(year,month)
	format t %tm
	drop monthdec

	sum ltrich mtrich

*                     Center and put onto decadal scale
	egen ave=mean(ltrich)
	replace ltrich=120*(ltrich-ave)
	drop ave
	egen ave=mean(mtrich)
	replace mtrich=120*(mtrich-ave)
	drop ave

*                     Do ARMA Regs to get trends
tsset t
arima ltrich t , ar(1/6)			 
arima mtrich t , ar(1/6) 				 

keep year month ltrich mtrich
capture save "rich.dta", replace
clear 



**************************************************************************************************************************
*
* 	READ IN .DTA FILES AND MERGE INTO lt.dta and mt.dta
*
**************************************************************************************************************************


*	LT MERGE OPERATIONS
use "model_lt.dta"
	merge using "uahlt.dta"
	drop _merge
	save mu.dta, replace
	clear

use mu.dta
	merge using "rsslt.dta"
	drop _merge
	save mu.dta, replace
	clear

use mu.dta
	merge using "had.dta"
	drop _merge mthad
	save mu.dta, replace
	clear

use mu.dta
	merge using "rich.dta"
	drop _merge mtrich
	save mu.dta, replace

	drop if year>2009
	sum
	save lt.dta, replace
	clear

*	MT MERGE OPERATIONS
use "model_mt.dta"
	merge using "uahmt.dta"
	drop _merge
	save mu.dta, replace
	clear

use mu.dta
	merge using "rssmt.dta"
	drop _merge
	save mu.dta, replace
	clear

use mu.dta
	merge using "had.dta"
	drop _merge lthad
	save mu.dta, replace
	clear

use mu.dta
	merge using "rich.dta"
	drop _merge ltrich
	save mu.dta, replace

	drop if year>2009
	sum
	save mt.dta, replace
	clear

exit



